.. HyperSpy documentation master file, created by
   sphinx-quickstart on Mon Oct 18 11:10:55 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to HyperSpy's documentation!
===================================


.. toctree::
    :maxdepth: 3

    user_guide/index.rst
    credits.rst
    citing.rst    

   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

